@@ -20,7 +20,6 @@ use {
         get_context_value, optional_bool_arg, optional_str_arg, EnvironmentContext,
     },
     std::{
-        convert::TryFrom,
         path::PathBuf,
         sync::{Arc, Mutex, MutexGuard},
     },
@@ -140,7 +139,7 @@ impl FileContentValue {
         let executable = optional_bool_arg("executable", &executable)?;
 
         if let Some(filename) = &filename {
-            validate_filename(LABEL, &filename)?;
+            validate_filename(LABEL, filename)?;
         }
 
         let cwd = {
@@ -334,7 +333,7 @@ mod tests {
         let inner = v.inner("ignored").unwrap();
 
         assert_eq!(inner.filename, "file");
-        assert_eq!(inner.content.is_executable(), false);
+        assert!(!inner.content.is_executable());
         assert_eq!(inner.content.resolve_content()?, b"foo".to_vec());
 
         Ok(())
@@ -346,13 +345,13 @@ mod tests {
 
         env.eval("c = FileContent(filename = 'file', content = 'foo')")?;
 
-        assert_eq!(env.eval("c.executable")?.to_bool(), false);
+        assert!(!env.eval("c.executable")?.to_bool());
         assert_eq!(env.eval("c.filename")?.to_string(), "file");
 
         env.eval("c.executable = True")?;
         env.eval("c.filename = 'renamed'")?;
 
-        assert_eq!(env.eval("c.executable")?.to_bool(), true);
+        assert!(env.eval("c.executable")?.to_bool());
         assert_eq!(env.eval("c.filename")?.to_string(), "renamed");
 
         Ok(())
